Enum style::values::specified::color::Color
[−]
[src]
pub enum Color {
CurrentColor,
Numeric {
parsed: RGBA,
authored: Option<Box<str>>,
},
Complex(ComputedColor),
}Specified color value
Variants
CurrentColorThe 'currentColor' keyword
NumericA specific RGBA color
Fields of Numeric
parsed: RGBA | Parsed RGBA color |
Authored representation |
Complex(ComputedColor)A complex color value from computed value
Methods
impl Color[src]
pub fn currentcolor() -> Color[src]
Returns currentcolor value.
pub fn transparent() -> Color[src]
Returns transparent value.
pub fn rgba(rgba: RGBA) -> Self[src]
Returns a numeric RGBA color value.
pub fn parse_quirky<'i, 't>(
context: &ParserContext,
input: &mut Parser<'i, 't>,
allow_quirks: AllowQuirks
) -> Result<Self, ParseError<'i>>[src]
context: &ParserContext,
input: &mut Parser<'i, 't>,
allow_quirks: AllowQuirks
) -> Result<Self, ParseError<'i>>
Parse a color, with quirks.
https://quirks.spec.whatwg.org/#the-hashless-hex-color-quirk
pub fn is_non_transparent(&self) -> bool[src]
Returns false if the color is completely transparent, and true otherwise.
impl Color[src]
pub fn to_computed_color(
&self,
_context: Option<&Context>
) -> Option<ComputedColor>[src]
&self,
_context: Option<&Context>
) -> Option<ComputedColor>
Converts this Color into a ComputedColor.
If context is None, and the specified color requires data from
the context to resolve, then None is returned.